C ********************************************************************
C * EDiT - Electronic Dipole-induced Transitions                     *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************

C ********************************************************************
C *                                                                  *
C *  SUBROUTINE ABFNS                                                *
C *                                                                  *
C *  Routine of EDiT/CEDiT                                           *
C *  version for IBM-PC MS-DOS, Microsoft FORTRAN and                *
C *              IBM-RISC UNIX, AIX XL FORTRAN                       *
C *                                                                  *
C *  Usage......: Calculates AB-functions.                           *
C *                                                                  *
C *  Authors....: unknown                                            *
C *                                                                  *
C *  Available..: Calzaferri group c/o                               *
C *               Prof. Dr. Gion Calzaferri                          *
C *               Department of Chemistry and Biochemistry           *
C *               University of Berne                                *
C *               Freiestrasse 3                                     *
C *               CH-3012 Berne                                      *
C *                                                                  *
C *  Date.......: -                                                  *
C *  Revision...: -                                                  *
C *                                                                  *
C *  Remarks....: -                                                  *
C *                                                                  *
C *  Called from: DOPELE                                             *
C *               DOSELE                                             *
C *               DODELE                                             *
C *               PODELE                                             *
C *               POPELE                                             *
C *               POSELE                                             *
C *               SODELE                                             *
C *               SOPELE                                             *
C *               SOSELE                                             *
C *                                                                  *
C *  Calls......: -                                                  *
C *                                                                  *
C ********************************************************************

      SUBROUTINE ABFNS(A, B, SK1, SK2, RR, MAXCAL)

      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

        DOUBLE PRECISION  A(20), B(20), SK1, SK2, RR
        INTEGER  MAXCAL, IR

C BEGIN
      J=MAXCAL+1
      RHO1=0.5D0*(SK1+SK2)*RR
      RHO2=0.5D0*(SK1-SK2)*RR
      IF (DABS(RHO1).GT.165.D0) GOTO 100
      IF (DABS(RHO2).GT.165.D0) GOTO 100
      C=DEXP(-RHO1)
      A(1)=C/RHO1
      DO 15 I=2,J
 15     A(I)=(DBLE(I-1)*A(I-1)+C)/RHO1
      IX=J
      IR=INT(DABS(2.0D0*RHO2))
      IS=MIN0(IR+1,19)
      IF (RHO2) 25,35,25
 25   D=DEXP(RHO2)
      H=1.D0/D
C
C  IF THE VALUE OF RHO2 IS TOO SMALL THE SINH MUST BE OBTAINED
C  BY SUMMING THE INFINITE SERIES RATHER THAN BY ADDITION OF
C  TWO EXPONENTIALS.
C
      R=D-H
      IF (DABS(R)-0.1) 26,28,28
 26   RA=RHO2
      RHO22=RHO2*RHO2
      T=RHO2
      DO 27 I=2,50,2
        T=T*RHO22/DBLE(I*I+I)
        RA=RA+T
        IF (T.LT.1.D-30) GO TO 999
 27   CONTINUE
 999  CONTINUE
      R=RA+RA
C
C  AS MANY SUCCESSIVE B-FUNCTIONS ARE GENERATED FROM B-0 BY THE
C  RECURRENCE FORMULAE AS ACCURACY WILL PERMIT.
C
28    B(1)=R/RHO2
      DO 51 I=2,IX,IS
        IF (IR.EQ.0) GO TO 40
32      IL=IS-1
        IF (1.GT.IL) GO TO 9050
        DO 31 J=1,IL
          K=I+J-1
          IF ((-1)**K) 29,29,30
29        B(K)=(R+DBLE(K-1)*B(K-1))/RHO2
          GOTO 31
30        B(K)=-(D+H-DBLE(K-1)*B(K-1))/RHO2
31      CONTINUE
9050    CONTINUE
40      IN=I+IS-1
C
C  AFTER THE RECURRENCE FORMULAE HAVE BEEN APPLIED AN APPROPRIATE
C  NUMBER OF TIMES THE NEXT B-FUNCTION IS OBTAINED BY SUMMATION
C  OF THE INFINITE SERIES.
C
        IF (IN-IX) 39,39,38
39      IF ((-1)**IN) 44,44,42
42      TR=RHO2
105     B(IN)=-2.*TR/DBLE(IN+1)
        DO 43 J=1,500
          TR=TR*RHO2**2/DBLE((2*J)*(2*J+1))
          IF (DABS(TR/B(IN))-1.0D-7) 51,51,43
43        B(IN)=B(IN)-2.*TR/DBLE(IN+1+2*J)
44      TR=1.
107     B(IN)=2.*TR/DBLE(IN)
        DO 46 J=1,500
          TR=TR*RHO2**2/DBLE((2*J)*(2*J-1))
          IF (DABS(TR/B(IN))-1.0D-7) 51,51,46
46        B(IN)=B(IN)+2.*TR/DBLE(IN+2*J)
51    CONTINUE
C
C  IF THE ARGUMENT IS ZERO A SEPARATE FORMULA MUST BE USED.
C
      GOTO 38
35    DO 36 I=1,IX,2
        B(I)=2.D0/DBLE(I)
36      B(I+1)=0.D0
38    RETURN
100   DO 101 I=1,20
        A(I)=0.D0
101     B(I)=0.D0
      GOTO 38
      END
C END
