C ********************************************************************
C * ICONC - Extended Hueckel Calculations                            *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************

C ********************************************************************
C *                                                                  *
C *  SUBROUTINE DELETS                                               *
C *                                                                  *
C *  Routine of ICONC(S)                                             *
C *                                                                  *
C *  Usage......: Sets certain overlap integrals equal to zero.      *
C *                                                                  *
C *  Authors....:                                                    *
C *  Available..: Calzaferri group c/o                               *
C *               Prof. Dr. Gion Calzaferri                          *
C *               Department of Chemistry and Biochemistry           *
C *               University of Berne                                *
C *               Freiestrasse 3                                     *
C *               CH-3012 Berne                                      *
C *                                                                  *
C *  Date.......: -                                                  *
C *  Revision...: last revision 24.08.97/mbs (Martin Braendle)       *
C *  Remarks....: SORB now passed by COMMON block FMO.               *
C *                                                                  *
C *  Called from: MOVLAP                                             *
C *                                                                  *
C *  Calls......: -                                                  *
C *                                                                  *
C ********************************************************************
 
      SUBROUTINE DELETS(S,COUL0,NDIM)
 
      INCLUDE 'iconpara.for'
 
      IMPLICIT REAL*8(A-H,O-Z)
      DIMENSION S(NDIM,NDIM),COUL0(20)
      INTEGER*4 COUL0
 
      COMMON/CNTRL/CON,PEEP,COULH,NH,NA,NATM,KA,NELEC,METH,IPRINT,
     .             IPUNCH,L1,L2,L3,L4,L5,L6,L7,L8,L9,ONEMAT,ITERAT
      LOGICAL*1 L1,L2,L3,L4,L5,L6,L7,L8,L9,ONEMAT,ITERAT
 
      COMMON/OUT/PRT(24),PUN(24),IOVPOP(24),IENRGY(24)
      LOGICAL*1 PRT,PUN
      INTEGER   IOVPOP,IENRGY
 
      COMMON/FMO/FMO(MXATOM),FMOCH(9),SORA(MXATOM),SORB(MXATOM),
     .           NFRAG(9),NUMBAT(9),IFMOPT(4*MXATOM),IBCKPT(MXATOM),
     .           PRIFMO(7)
      INTEGER FMO,FMOCH,SORA,SORB
      LOGICAL*1 PRIFMO
 
      LOGICAL*1 IERR
      CHARACTER*8 ORBTL,ATMPR,X1,X2
      DATA ORBTL/' ORBITAL'/,ATMPR/'  ATOM  '/
 
      SORB(NA+1)=NDIM+1
      IERR=.FALSE.
C
C  READ IN NUMBERS INDICATING WHICH OVERLAP INTEGRALS ARE TO BE SET
C  TO ZERO. A POSITIVE NUMBER REFERS TO AN ATOM, A NEGATIVE ONE TO
C  AN ORBITAL.
C
10    READ(5,*,END=300) COUL0
1000  FORMAT(20I3)
      DO 200 IDEL=1,19,2
        I=COUL0(IDEL)
        J=COUL0(IDEL+1)
C
C  TERMINATE ON ENCOUNTERING A ZERO.
C
        IF (I.EQ.0.OR.J.EQ.0) GOTO 400
        IF (IERR) GOTO 200
        IABSV=IABS(I)
        JABSV=IABS(J)
        IF (I.GT.NH) GOTO 20
C
C  I REFERS TO ORBITAL (NEGATIVE) OR H ATOM (POSITIVE,LE NH).
C
        ILOW=IABSV
        IHIGH=IABSV
C
C  ERROR IF I OUT OF RANGE OF ORBITAL NUMBERS.
C
        IF (IABSV.GT.NDIM) GOTO 160
        GOTO 30
C
C  ERROR IF I OUT OF RANGE OF ATOMS.
C
20      IF (I.GT.NATM) GOTO 160
        ILOW=SORB(IABSV-NH)
        IHIGH=SORB(IABSV-NH+1)-1
30      IF (J.GT.NH) GOTO 40
        JLOW=JABSV
        JHIGH=JABSV
C
C  CHECK TO SEE IF J IS IN RANGE.
C
        IF (JABSV.GT.NDIM) GOTO 160
        GOTO 50
40      IF (J.GT.NATM) GOTO 160
        JLOW=SORB(JABSV-NH)
        JHIGH=SORB(JABSV-NH+1)-1
50      X1=ATMPR
        IF (I.LT.0) X1=ORBTL
        X2=ATMPR
        IF (J.LT.0) X2=ORBTL
        IF (.NOT.PRT(2)) WRITE(6,1002) X1,IABSV,X2,JABSV
1002    FORMAT('0ALL S(I,J) SET TO ZERO BETWEEN',A8,I4,' AND',A8,I4,'.')
C
C  J MUST BE LESS THAN OR EQUAL TO I SINCE WE ONLY HAVE A HALF
C  MATRIX AT THIS POINT.
C
        IF (JHIGH.LE.IHIGH) GOTO 60
        I=JHIGH
        JHIGH=IHIGH
        IHIGH=I
        I=JLOW
        JLOW=ILOW
        ILOW=I
60      DO 100 I=ILOW,IHIGH
          DO 100 J=JLOW,JHIGH
100         S(J,I)=0.D0
        GOTO 200
160     IERR=.TRUE.
        WRITE(6,1003) COUL0
1003    FORMAT('0NUMBER OUT OF RANGE IN FOLLOWING DELETION CARD'/'0',
     .         20I5,/,'0NO FURTHER DELETIONS, BUT SCANNING FOR ZERO TO',
     .         ' TERMINATE CARD READING.')
200   CONTINUE
      GOTO 10
300   WRITE(6,1004)
1004  FORMAT('0END OF FILE IN DELETION CARDS, NO FURTHER DELETIONS.')
400   RETURN
      END
