C ********************************************************************
C * ICONC - Extended Hueckel Calculations                            *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************

C ********************************************************************
C *                                                                  *
C *  SUBROUTINE FMOS                                                 *
C *                                                                  *
C *  Routine of ICONC                                                *
C *                                                                  *
C *  Usage......: Fills fragment overlap and hamiltonian matrices    *
C *               from the molecular S and H matrices. Actual fil-   *
C *               ling will be done in subroutine FMOT.              *
C *                                                                  *
C *  Author ....: Charles Wilker (R. Hoffmann group)                 *
C *  Date.......: December 1981                                      *
C *  Revision...: last revision 24.08.97/mbs (Martin Braendle)       *
C *  Available..: Prof. Dr. Gion Calzaferri                          *
C *               Department of Chemistry and Biochemistry           *
C *               University of Berne                                *
C *               Freiestrasse 3                                     *
C *               CH-3012 Berne                                      *
C *  Remarks....: Adapted from the BIGICON version                   *
C *                                                                  *
C *  Called from: HUCKEL                                             *
C *                                                                  *
C *  Calls......: FMOT                                               *
C *                                                                  *
C ********************************************************************
 
      SUBROUTINE FMOS(H,S, H1,H2,H3,H4,H5,H6,H7,H8,H9, S1,S2,S3,S4,S5,
     . S6,S7,S8,S9, NDIM,NATOM,ND1,ND2,ND3,ND4,ND5,ND6,ND7,ND8,ND9)
 
      INCLUDE 'iconpara.for'
 
      IMPLICIT REAL*8(A-H,O-Z)
 
      INTEGER ND1,ND2,ND3,ND4,ND5,ND6,ND7,ND8,ND9
      DIMENSION H(NDIM,NDIM),S(NDIM,NDIM)
      DIMENSION H1(ND1,ND1),S1(ND1,ND1)
      DIMENSION H2(ND2,ND2),S2(ND2,ND2)
      DIMENSION H3(ND3,ND3),S3(ND3,ND3)
      DIMENSION H4(ND4,ND4),S4(ND4,ND4)
      DIMENSION H5(ND5,ND5),S5(ND5,ND5)
      DIMENSION H6(ND6,ND6),S6(ND6,ND6)
      DIMENSION H7(ND7,ND7),S7(ND7,ND7)
      DIMENSION H8(ND8,ND8),S8(ND8,ND8)
      DIMENSION H9(ND9,ND9),S9(ND9,ND9)
 
      COMMON/FMO/FMO(MXATOM),FMOCH(9),SORA(MXATOM),SORB(MXATOM),
     .           NFRAG(9),NUMBAT(9),IFMOPT(4*MXATOM),IBCKPT(MXATOM),
     .           PRIFMO(7)
      INTEGER FMO,FMOCH,SORA,SORB
      LOGICAL*1 PRIFMO
 
      IF (NFRAG(1).LE.0) RETURN
      CALL FMOT(H,S,H1,S1, NDIM,NATOM,ND1,1)
      IF (NFRAG(2).LE.0) RETURN
      CALL FMOT(H,S,H2,S2, NDIM,NATOM,ND2,2)
      IF (NFRAG(3).LE.0) RETURN
      CALL FMOT(H,S,H3,S3, NDIM,NATOM,ND3,3)
      IF (NFRAG(4).LE.0) RETURN
      CALL FMOT(H,S,H4,S4, NDIM,NATOM,ND4,4)
      IF (NFRAG(5).LE.0) RETURN
      CALL FMOT(H,S,H5,S5, NDIM,NATOM,ND5,5)
      IF (NFRAG(6).LE.0) RETURN
      CALL FMOT(H,S,H6,S6, NDIM,NATOM,ND6,6)
      IF (NFRAG(7).LE.0) RETURN
      CALL FMOT(H,S,H7,S7, NDIM,NATOM,ND7,7)
      IF (NFRAG(8).LE.0) RETURN
      CALL FMOT(H,S,H8,S8, NDIM,NATOM,ND8,8)
      IF (NFRAG(9).LE.0) RETURN
      CALL FMOT(H,S,H9,S9, NDIM,NATOM,ND9,9)
 
      RETURN
      END
