C ********************************************************************
C * ICONC - Extended Hueckel Calculations                            *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************

C ********************************************************************
C *                                                                  *
C *  SUBROUTINE HUCK                                                 *
C *                                                                  *
C *  Routine of ICONC(S)                                             *
C *                                                                  *
C *  Usage......: solves eigenvalue problem                          *
C *                                                                  *
C *  Authors....: -                                                  *
C *  Available..: Calzaferri group c/o                               *
C *               Prof. Dr. Gion Calzaferri                          *
C *               Department of Chemistry and Biochemistry           *
C *               University of Berne                                *
C *               Freiestrasse 3                                     *
C *               CH-3012 Berne                                      *
C *                                                                  *
C *  Date.......: 30.10.90/mbs (Martin Braendle)                     *
C *  Remarks....: Adapted from a part of the subroutine HUCKEL of    *
C *               ICONC and from the subroutine HUCK of the BIGICON  *
C *               version from the Roald Hoffmann group.             *
C *  Revision...: last revision 17.10.91/mbs                         *
C *  Remarks....: Calling of Gram-Schmidt transformation of the      *
C *               overlap matrix imported from subroutine HUCKEL.    *
C *               NC instead of NDIM will be used for dimensioning   *
C *               of array C in subroutines GRMSCH and TRNFRM.       *
C *               18.01.91/mbs                                       *
C *                                                                  *
C *  Called from: HUCKEL                                             *
C *               FMOR                                               *
C *                                                                  *
C *  Calls......: GRMSCH                                             *
C *               TRNFRM                                             *
C *               GIVENS                                             *
C *               OUTPUT                                             *
C *               ITRATE                                             *
C *                                                                  *
C ********************************************************************
 
      SUBROUTINE HUCK(H,S,MAD,C,SP,COUL0,W,IOCC,HDG, NDIM,NC,NATOM,
     .                NTYPE,NHDG)
 
      INCLUDE 'iconpara.for'
 
      IMPLICIT REAL*8(A-H,O-Z)
 
      DIMENSION H(NDIM,NDIM),S(NDIM,NDIM),MAD(NTYPE,NTYPE)
      DIMENSION C(NC),SP(NDIM),COUL0(NDIM),W(NDIM),IOCC(NDIM)
      DIMENSION HDG(NHDG)
      REAL*8 MAD
      REAL*4 IOCC
 
      COMMON/TITLE/AB(10)
 
      COMMON/CNTRL/CON,PEEP,COULH,NH,NA,NATM,KA,NELEC,METH,
     . IPRINT,IPUNCH,L1,L2,L3,L4,L5,L6,L7,L8,L9,ONEMAT,ITERAT
      LOGICAL*1 L1,L2,L3,L4,L5,L6,L7,L8,L9,ONEMAT,ITERAT
 
      COMMON/OUT/PRT(24),PUN(24),IOVPOP(24),IENRGY(24)
      LOGICAL*1 PRT,PUN
      INTEGER IOVPOP,IENRGY
 
      COMMON/ITPARM/DAMP1,DAMP2,DAMP3,LAMPRI,DELTAC,SENSE,MAXCYC,
     .              PRTCYC,ICYCLE,NCON,PARTIT,PRINTX,ITABLE(MXITER)
      REAL*8 LAMPRI
      LOGICAL*1 PARTIT,PRINTX,ITABLE
      INTEGER*4 PRTCYC
 
      LOGICAL*1 FLAG
 
 
C
C  Orthogonalise basis set by Gram-Schmidt transformation. When doing
C  charge iteration the overlap matrix has already been transformed
C  after the first cycle. 19.11.90/mbs
C
      IF (ICYCLE.GT.1) GOTO 100
      CALL GRMSCH(S,C,NDIM,NC)
 
C
C  CALL TRNFRM TO TRANSFORM HUCKEL MATRIX TO ORTHOGONAL BASIS SET.
C  THEN CALL GIVENS TO PERFORM DIAGONALIZATION.
C
100   IH=1
      IF (ONEMAT) IH=2
      CALL TRNFRM(H,S,C,COUL0,SP,NDIM,NC,IH)
      IF (ONEMAT) THEN
        IH=-NDIM
      ELSE 
        IH=NDIM
      ENDIF
120   CALL GIVENS(NDIM,IH,NDIM,C,SP,COUL0,H)
130   IF (ICYCLE.GE.10000) ITERAT=.FALSE.
C
C  PRINT OUT TITLE, ENERGY LEVELS, AND OCCUPATION NUMBERS.
C
      IF (ITERAT) GOTO 700
      IF (METH.EQ.0) WRITE(6,701) AB
701   FORMAT ('1RESULTS OF CALCULATION   ',8A8,A6,A2,/)
      IF (PRT(8)) GOTO 710
      WRITE(6,702) (I,COUL0(I),IOCC(I),I=1,NDIM)
702   FORMAT(/,1X,'ENERGY LEVELS (eV)',//,(3X,'E(',I3,') =',F12.5,
     .       16X,F6.4))
C
C  WRITE ENERGY LEVELS INTO FILE ENERNI.DAT. THIS FILE CAN BE READ BY
C  THE ASYST PROGRAM ENERNI.EHM, WHICH MAKES A PICTURE OF THE ENERGY
C  LEVELS
C     THIS FILE IS ALREADY OPEN (TH)
C     OPEN(UNIT=1,FILE='ENERNI.DAT',STATUS='UNKNOWN')
C
      WRITE (1,411)NDIM
411   FORMAT(I3)
      WRITE(1,412)(COUL0(I),I=1,NDIM)
412   FORMAT(F12.5)
C     CLOSE(UNIT=1)
710   IF (PUN(8)) WRITE(7,825) (COUL0(I),I=1,NDIM)
825   FORMAT(8F9.5)
700   IF (ONEMAT) GOTO 200
C
C  DIDDLE WITH C,H.
C
      DO 160 J=1,NDIM
        DO 140 K=1,NDIM
140       C(K)=H(K,IH)
        DO 155 I=1,NDIM
        ET=0.D0
        DO 150 K=I,NDIM
150       ET=ET+S(I,K)*C(K)
155     H(I,IH)=ET
160     IH=IH-1
      K=1
      DO 180 I=2,NDIM
        IL=I-1
        DO 180 J=1,IL
          C(K)=S(I,J)
180       K=K+1
 
200   IF (METH.GT.1.AND.ITERAT) GOTO 210
C
C  CALL OUTPUT FOR FINAL PRINT OUT OF RESULTS.
C  SORB changed to W. Flags and I added. 30.10.90/mbs
C
      FLAG=.FALSE.
      CALL OUTPUT(H,S,MAD,C,COUL0,W,IOCC,HDG, NDIM,NATOM,NTYPE,NC,NHDG,
     .            FLAG,I)
      IF (.NOT.ITERAT) RETURN
C
C  IF DOING CHARGE ITERATIVE CALCULATION ( METH =1 ), CALL ITRATE
C  TO SETUP HUCKEL MATRIX.
C  SORB changed to W. 30.10.90/mbs
C
210   CALL ITRATE(H,S,MAD,C,COUL0,W,IOCC,HDG,NDIM,NTYPE,NC,NHDG)
      RETURN
      END
