C ********************************************************************
C * ICONC - Extended Hueckel Calculations                            *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************

C ********************************************************************
C *                                                                  *
C *  SUBROUTINE NEWDIA                                               *
C *                                                                  *
C *  Routine of ICONC(S)                                             *
C *                                                                  *
C *  Usage......: CALCULATES HUECKELCONSTANT K WITH                  *
C *               K=1+kappa*EXP(-delta*(R-d0))/q                                                   *
C *                             where q=1+(((R-d0)-R-d0)*delta)**2                     *
C *               kappa is calculated according to the weighted      *
C *               Wolfsberg-Helmholz formula                         *
C *               R : DISTANCE BETWEEN TWO ATOMS                     *
C *                                                                  *
C *  Authors....: Gion Calzaferri, Lars Forss c/o                    *
C *               Calzaferri group                                   *
C *               Prof. Dr. Gion Calzaferri                          *
C *               Department of Chemistry and Biochemistry           *
C *               University of Berne                                *
C *               Freiestrasse 3                                     *
C *               CH-3012 Berne                                      *
C *                                                                  *
C *  Date.......: August 87                                          *
C *  Revision...: last revision 05.05.93/mbs (Martin Braendle)       *          
C *  Remarks....: Individual k-parameter specifications for several  *
C *               atom pairs added.                                  *
C *               Subroutine completely changed and reoptimized. The *
C *               orbital radii will now be calculated in routine    *
C *               ORBRAD.                                            *
C *                                                                  *
C *  Called from: HUCKEL,ITRATE                                      *
C *                                                                  *
C *  Calls......: -                                                  *
C *                                                                  *
C ********************************************************************
 
      SUBROUTINE NEWDIA(H,S,NDIM)
 
      INCLUDE 'iconpara.for'
 
      IMPLICIT REAL*8(A-H,O-Z)
      DIMENSION H(NDIM,NDIM),S(NDIM,NDIM)
 
      COMMON/ANEWDI/CWK,CWKALP,R(MXATOM,MXATOM)
 
      COMMON/CNTRL/CON,PEEP,COULH,NH,NA,NATM,KA,NELEC,METH,IPRINT,
     .             IPUNCH,L1,L2,L3,L4,L5,L6,L7,L8,L9,ONEMAT,ITERAT
      LOGICAL*1 L1,L2,L3,L4,L5,L6,L7,L8,L9,ONEMAT,ITERAT
 
      COMMON/KSET/KATOM(MXSETK,2),SETK(MXSETK),SETD(MXSETK),NKSET
      INTEGER NKSET,KATOM
 
      COMMON /ORBRD/D0(4*MXATOM)
      COMMON /ATOMPT/IATMPT(4*MXATOM)
 
      DO 40 I=1,NDIM-1
        IATOM1=IATMPT(I)
        DO 30 J=I+1,NDIM
          CONST=(1.0+CWK)/2.0D0
          CDELTA=CWKALP
          IATOM2=IATMPT(J)
          IF (L7) THEN
            DO 10 IATOM=1,NKSET
              IF (((IATOM1 .EQ. KATOM(IATOM,1)) .AND.
     .             (IATOM2 .EQ. KATOM(IATOM,2))) .OR.
     .            ((IATOM1 .EQ. KATOM(IATOM,2)) .AND.
     .             (IATOM2 .EQ. KATOM(IATOM,1)))) THEN
                CONST=SETK(IATOM)/2.0D0
                IF (SETD(IATOM).GT.1.D-3) THEN
                  CDELTA=SETD(IATOM)
                ENDIF
                GOTO 20
              ENDIF
10          CONTINUE
          ENDIF
20        HH=H(I,I)+H(J,J)
          ET=(H(I,I)-H(J,J))/HH
          ET=ET*ET
          CNST=CONST+ET/2.0D0+ET*ET*(0.5D0-CONST)
          ORBRD=D0(I)+D0(J)
          ABDIST=R(IATOM1,IATOM2)
          RDIF=ABDIST-ORBRD
          RD2=(RDIF-DABS(RDIF))*CDELTA
          CNST=1.D0+(2.D0*CNST-1.D0)*DEXP(-CDELTA*RDIF)/(1.D0+RD2*RD2)
          CNST=CNST/2.0D0
          H(J,I)=CNST*HH*S(J,I)
          H(I,J)=H(J,I)
30      CONTINUE
40    CONTINUE
      RETURN
      END
