C ********************************************************************
C * ICONC - Extended Hueckel Calculations                            *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************

C ********************************************************************
C *                                                                  *
C *  SUBROUTINE REP                                                  *
C *                                                                  *
C *  Routine of ICONC(S)                                             *
C *                                                                  *
C *  Usage......: Calculates integral over (electron density divided *
C *               difference of core vector and electron vector).    *
C *                                                                  *
C *  Authors....: Calzaferri group c/o                               *
C *               Prof. Dr. Gion Calzaferri                          *
C *               Department of Chemistry and Biochemistry           *
C *               University of Berne                                *
C *               Freiestrasse 3                                     *
C *               CH-3012 Berne                                      *
C *                                                                  *
C *  Date.......: -                                                  *
C *  Revision...: last revision 25.08.97/mbs (Martin Braendle)       *
C *  Remarks....: If ns np nd configurations are calculated, the d-  *
C *               orbitals will not contribute to the repulsion in-  *
C *               tegral as in the ns np (n-1)d case. 21.11.91/mbs   *
C *                                                                  *
C *  Called from: REPUL                                              *
C *                                                                  *
C *  Calls......: DESORB,RECALL                                      *
C *                                                                  *
C ********************************************************************
 
      SUBROUTINE REP(R,EREP,IATOM,KEYI)
 
      INCLUDE 'iconpara.for'
 
      IMPLICIT REAL*8(A-H,O-Z)
 
      COMMON /ATOM/EXPS(MXATOM),EXPP(MXATOM),EXPD(MXATOM),EXPD2(MXATOM),
     .             C1(MXATOM),C2(MXATOM),COULS(MXATOM),COULP(MXATOM),
     .             COULD(MXATOM),X(MXATOM),Y(MXATOM),Z(MXATOM),
     .             KEY(MXATOM),AC(MXATOM),VELEC(MXATOM),NS(MXATOM),
     .             NP(MXATOM),ND(MXATOM)
      INTEGER AC,VELEC,KEY
 
      COMMON /CNTRL/CON,PEEP,COULH,NH,NA,NATM,KA,NELEC,METH,IPRINT,
     .              IPUNCH,L1,L2,L3,L4,L5,L6,L7,L8,L9,ONEMAT,ITERAT
      LOGICAL*1 L1,L2,L3,L4,L5,L6,L7,L8,L9,ONEMAT,ITERAT
 
      COMMON/ENERGY/HSS(MXATOM),HPP(MXATOM),HDD(MXATOM)

      EREP=0.0D0
      IF (METH .GT. 0) THEN
        IF (NS(KEYI) .NE. 0) THEN
          COUS=HSS(IATOM)
        ELSE
          COUS=0.0D0
        ENDIF
        IF (NP(KEYI) .NE. 0) THEN
          COUP=HPP(IATOM)
        ELSE
          COUP=0.0D0
        ENDIF
        IF (ND(KEYI) .NE. 0) THEN
          COUD=HDD(IATOM)
        ELSE
          COUD=0.0D0
        ENDIF
      ELSE
        COUD=COULD(KEYI)
        COUP=COULP(KEYI)
        COUS=COULS(KEYI)
      ENDIF
      CALL DESORB(COUD,COUP,COUS,IATOM,IOCCS,IOCCP,IOCCD,KEYI)
 
      IF (ND(KEYI) .GT. 0) THEN
        IF ((NS(KEYI)-ND(KEYI)) .EQ. 1) THEN
          N=ND(KEYI)
          SE=EXPD(KEYI)*2/0.529177D0
          CALL RECALL(N,R,SE,WB1)
          SE=EXPD2(KEYI)*2/0.529177D0
          CALL RECALL(N,R,SE,WB2)
          SE=(EXPD(KEYI)+EXPD2(KEYI))/0.529177D0
          CALL RECALL(N,R,SE,WB3)
          EREP=(C1(KEYI)**2)*WB1+(C2(KEYI)**2)*WB2+C1(KEYI)
     .         *C2(KEYI)*2*WB3
          EREP=1/R-EREP
          EREP=EREP*DBLE(IOCCD)
        ENDIF
      ENDIF
 
      N=NS(KEYI)
      SE=EXPS(KEYI)*2.0/0.529177D0
      CALL RECALL(N,R,SE,WB1)
      WB1=1/R-WB1
      EREP=EREP+WB1*DBLE(IOCCS)
 
      IF (IOCCP .GT. 0) THEN
        SE=EXPP(KEYI)*2/0.529177D0
        CALL RECALL(N,R,SE,WB1)
        WB1=1/R-WB1
        EREP=EREP+WB1*DBLE(IOCCP)
      ENDIF
      RETURN
      END
