C ********************************************************************
C * INPUTC - Input Program for ICONC                                 *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************

C ********************************************************************
C *                                                                  *
C *  SUBROUTINE FMSPEC                                               *
C *                                                                  *
C *  Routine of INPUTC                                               *
C *                                                                  *
C *  Usage......: sets FMO specifications                            *
C *                                                                  *
C *  Author.....: Martin Braendle (mbs)                              *
C *               Calzaferri group c/o                               *
C *               Prof. Dr. Gion Calzaferri                          *
C *               Department of Chemistry and Biochemistry           *
C *               Freiestrasse 3                                     *
C *               3012 Berne                                         *
C *                                                                  *
C *  Date.......: 01.10.90                                           *
C *  Revision...: last revision 17.10.91/mbs                         *
C *  Remarks....: COMMON block PARAM extended.                       *
C *                                                                  *
C *  Called from: PARAMET                                            *
C *                                                                  *
C *  Calls......: -                                                  *
C *                                                                  *
C ********************************************************************
C
      SUBROUTINE FMSPEC
      IMPLICIT REAL(A-H,O-Z)
 
      INCLUDE 'inpupara.for'
 
      LOGICAL   INPAT
      CHARACTER ANSWER
 
      COMMON/PARAM/NH,NA,KA,METH,IPRINT,IPUNCH,L1,L2,L3,L4,L5,L6,L7,
     .             L8,L9,PRT
      LOGICAL L1,L2,L3,L4,L5,L6,L7,L8,L9,PRT(24)
 
      COMMON/FMO/NFMO,FMO(MXATOM),FMOCH(9),PRIFMO(7)
      INTEGER NFMO,FMO,FMOCH
      LOGICAL PRIFMO
 
      L6=.TRUE.
      WRITE(6,10)
   10 FORMAT(//,' FMO (Fragment Molecular Orbitals) Specifications.')
   20 WRITE(6,30)
   30 FORMAT(/,' Enter number of fragments: ',$)
      READ(5,*,ERR=20) NFMO
      IF ((NFMO .LT. 2) .OR. (NFMO .GT. 9)) THEN
        WRITE(6,40)
   40   FORMAT(/,' Fragment number must be in the range 2..9.')
        GOTO 20
      ENDIF
 
   50 WRITE(6,60)
   60 FORMAT(/,' All atoms are now assigned to fragment # 1.',/,
     .       ' Enter atomnumbers for each fragment, beginning with ',
     .       'fragment # 2.',/,' Blank line skips to next fragment.',/)
      DO 150 I=2,NFMO
        INPAT=.FALSE.
   70   WRITE(6,80) I
   80   FORMAT(' Fragment #',I2,'. Enter atom #: ',$)
        READ(5,90,ERR=70) IATOM
   90   FORMAT(I3)
        IF (IATOM .GT. 0) THEN
          IF (IATOM .LE. NA) THEN
            INPAT=.TRUE.
            IF ((FMO(IATOM) .GT. 1) .AND. (FMO(IATOM) .NE. I)) THEN
  100         WRITE(6,110) IATOM, FMO(IATOM)
  110         FORMAT(' Warning: Atom #',I3,' is still assigned to ',
     .               'fragment #',I2,'. Overwrite it? [N] ',$)
              READ(5,120,ERR=100) ANSWER
  120         FORMAT(A1)
              IF (INDEX('YyJj',ANSWER) .LE. 0) GOTO 70
            ENDIF
            FMO(IATOM)=I
            GOTO 70
          ELSE
            WRITE(6,130) IATOM
  130       FORMAT(/,' Atom #',I3,' is not defined.')
            GOTO 70
          ENDIF
        ELSE
          IF ( .NOT. INPAT) THEN
            WRITE(6,140)
  140       FORMAT(' You have to define at least one atom for ',
     .             'this fragment.',/)
            GOTO 70
          ENDIF
        ENDIF
  150 CONTINUE
 
      DO 190 I=1,NFMO
        DO 160 J=1,NA
          IF (FMO(J) .EQ. I) GOTO 190
  160   CONTINUE
        WRITE(6,170) I
  170   FORMAT(/,' WARNING: No atom is assigned to fragment #',I2,'!')
        DO 180 J=1,NA
          FMO(J)=1
  180   CONTINUE
        GOTO 50
  190 CONTINUE
 
  200 SUMCH=0
      WRITE(6,210)
  210 FORMAT(/,' Enter integer charges for each fragment.',/)
      DO 250 I=1,NFMO
  220   WRITE(6,230) I
  230   FORMAT(' Charge on fragment #',I1,': ',$)
        READ(5,240,ERR=220) FMOCH(I)
  240   FORMAT(I3)
        SUMCH=SUMCH + FMOCH(I)
  250 CONTINUE
      IF (SUMCH .NE. KA) THEN
        WRITE(6,260)
  260   FORMAT(/,' WARNING: Sum of fragment charges does not equal ',
     .         'the molecular charge.')
        GOTO 200
      ENDIF
 
  270 WRITE(6,280)
  280 FORMAT(//,' All FMO print options are set. Change? [N] ',$)
      READ(5,290,ERR=270) ANSWER
  290 FORMAT(A1)
      IF (INDEX('YyJj',ANSWER) .GT. 0) THEN
        DO 300 I=1,7
          PRIFMO(I)=.TRUE.
  300   CONTINUE
        WRITE(6,310)
  310   FORMAT(//,' FMO print options:',//,
     .         '  1 Overlap matrix',/,
     .         '  2 Wavefunctions',/,
     .         '  3 Overlap population matrix',/,
     .         '  4 Reduced overlap population matrix',/,
     .         '  5 Complete charge matrix',/,
     .         '  6 Reduced charge matrix',/,
     .         '  7 Net charges and populations',//,
     .         '  8 Exit',/)
  320   WRITE(6,330)
  330   FORMAT(' Set FMO print option # : ',$)
        READ(5,340,ERR=320) IPRTOP
  340   FORMAT(I1)
        IF (IPRTOP .LT. 1) GOTO 320
        IF ((IPRTOP .GE. 1) .AND. (IPRTOP .LE. 7)) THEN
          PRIFMO(IPRTOP)=.FALSE.
          GOTO 320
        ENDIF
      ENDIF
 
      RETURN
      END
