C ********************************************************************
C * INPUTC - Input Program for ICONC                                 *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************

C ********************************************************************
C *                                                                  *
C *  INPUTC                                                          *
C *                                                                  *
C *  Usage......: Input fuer EHMO-Rechnungen mit ICONC(S)            *
C *                                                                  *
C *  Authors....: Gion Calzaferri, Lars Forss, Thomas Hugentobler,   *
C *               Martin Braendle (mbs) c/o                          *
C *               Prof. Dr. Gion Calzaferri                          *
C *               Department of Chemistry and Biochemistry           *
C *               Freiestrasse 3                                     *
C *               3012 Berne                                         *
C *                                                                  *
C *  Date.......: 07.12.1989                                         *
C *  Remarks....: For use with Microsoft FORTRAN Compiler Version 5.0*
C *               Should be compatible with VAX-FORTRAN (see NOTE)   *
C *                                                                  *
C *               NOTE: In this program we use the carriage-control  *
C *               character "\" in the FORMAT statements, which      *
C *               allows keyboard-input on the same line as previous *
C *               output. "\" has to be replaced by "$" in VAX-      *
C *               FORTRAN.                                           *
C *                                                                  *
C *               Benoetigt werden folgende Dateien im aktuellen     *
C *               Verzeichnis:  - VOI.DAT      Parameter zu VOIE     *
C *                             - FOI.DAT      Parameter zu VOIE     *
C *                             - ATOMDEF.DAT  Atomdaten             *
C *                                                                  *
C *               Programm INPUTC erstellt ein File, das direkt als  *
C *               Input fuer das EHMO-Programm ICONC verwendet       *
C *               werden kann.                                       *
C *                                                                  *
C *               Ab Version 5.0 (mit Internen Koordinaten) werden   *
C *               auch Files fuer die beiden Konversionsprogramme    *
C *               GENINSC und CONVERTC erstellt:                     *
C *               GENINSC  variiert die Internen Koordinaten und     *
C *               generiert mehrere Koordinatensaetze in Int. Koord. *
C *               CONVERTC konvertiert die int. Koordinatensaetze in *
C *               kartesische, welche dann als Input fuer ICONC be-  *
C *               nuetzt werden. Diese beiden Programme sind nun als *
C *               Subroutinen im Programm eingebaut.                 *
C *                                                                  *
C *  Revision...: last revision 01.06.92/mbs (Martin Braendle)       *
C *  Remarks....: FMO-Settings included, new subroutine FMSPEC/mbs   *
C *               Individual setting for 1+kappa-parameter (KSPEC),  *
C *               omitting of atoms in repulsion energy calculation  *
C *               (OMITAT)/mbs                                       *
C *               User specified atomic electron configuration added *
C *               01.06.92/mbs                                       *
C *                                                                  *
C *  Calls......: ATOMREAD                                           *
C *               INPFI                                              *
C *               CASE1                                              *
C *               GENIC                                              *
C *               CONVC                                              *
C *                                                                  *
C ********************************************************************
 
      BLOCK DATA
C
C Initialize internal atomic data. MXATOM user defined atoms and MXATMD
C internally defined atoms are provided.
C
C Variables:
C SYMBOL(MXSYMB) Format A3, Element 1-MXATOM for user input atom names.
C The definitions of ATOMDEF.DAT will be read in from element MXATOM+1
C to element MXSYMB.
C IATOM(MXATOM)  Format A2, Atomnames, as they are written in the ICON-
C inputfile after the coordinates, eg. '* C * * H H H H H'
C ITAT(MXITER)   Format A3, Atomnames of atoms to be charge iterated.
C
      IMPLICIT REAL(A-H,O-Z)
      INCLUDE 'inpupara.for'
 
      COMMON/AOOCC/NAOOCC,ICONF(MXAOOC,4)
 
      COMMON/ATDEF/IVELEC(MXSYMB),NS(MXSYMB),EXPS(MXSYMB),COULS(MXSYMB),
     .             NP(MXSYMB),EXPP(MXSYMB),COULP(MXSYMB),ND(MXSYMB),
     .             EXPD(MXSYMB),COULD(MXSYMB),C1(MXSYMB),EXPD2(MXSYMB),
     .             C2(MXSYMB)
 
      COMMON/CHART/MNAM,IATOM(MXATOM),SYMBOL(MXSYMB),ITAT(MXITER)
      CHARACTER*2  IATOM
      CHARACTER*3  SYMBOL,ITAT
      CHARACTER*80 MNAM
 
      COMMON/FMO/NFMO,FMO(MXATOM),FMOCH(9),PRIFMO(7)
      INTEGER NFMO,FMO,FMOCH
      LOGICAL PRIFMO
 
      COMMON/KSET/KATOM(MXSETK,2),SETK(MXSETK),SETD(MXSETK),NKSET
 
      COMMON /NEWDI/ CWK,CWKALP
 
      COMMON/OMITRP/NOMIT,OMIT(MXOMIT)
      INTEGER NOMIT,OMIT
 
      COMMON/PARAM/NH,NA,KA,METH,IPRINT,IPUNCH,L1,L2,L3,L4,L5,L6,L7,
     .             L8,L9,PRT
      LOGICAL L1,L2,L3,L4,L5,L6,L7,L8,L9,PRT(24)
 
      DATA SYMBOL/MXSYMB*'***'/
      DATA IVELEC/MXSYMB*0/
      DATA NS/MXSYMB*0/
      DATA EXPS/MXSYMB*0.0/
      DATA COULS/MXSYMB*0.0/
      DATA NP/MXSYMB*0/
      DATA EXPP/MXSYMB*0.0/
      DATA COULP/MXSYMB*0.0/
      DATA ND/MXSYMB*0/
      DATA EXPD/MXSYMB*0.0/
      DATA COULD/MXSYMB*0.0/
      DATA C1/MXSYMB*0.0/
      DATA C2/MXSYMB*0.0/
      DATA EXPD2/MXSYMB*0.0/
      DATA NFMO/0/,FMO/MXATOM*1/,FMOCH/9*0/
      DATA PRIFMO/7*.FALSE./
      DATA L6/.FALSE./
      DATA L7/.FALSE./
      DATA NKSET/0/
      DATA L8/.FALSE./
      DATA NOMIT/0/
      DATA CWK/2.0/
      DATA CWKALP /0.35/
      DATA L5/.FALSE./
      DATA IPUNCH /1/
      DATA L9/.FALSE./
      DATA NAOOCC/0/
      END
C
C Start des Hauptprogramms
C
      PROGRAM INPUTC
      IMPLICIT REAL(A-H,O-Z)
      INCLUDE 'inpupara.for'
 
      CHARACTER*32 FILE1,FILE2,FILE3
 
      COMMON/AOOCC/NAOOCC,ICONF(MXAOOC,4)
 
      COMMON/ATDEF/IVELEC(MXSYMB),NS(MXSYMB),EXPS(MXSYMB),COULS(MXSYMB),
     .             NP(MXSYMB),EXPP(MXSYMB),COULP(MXSYMB),ND(MXSYMB),
     .             EXPD(MXSYMB),COULD(MXSYMB),C1(MXSYMB),EXPD2(MXSYMB),
     .             C2(MXSYMB)
 
      COMMON/CHART/MNAM,IATOM(MXATOM),SYMBOL(MXSYMB),ITAT(MXITER)
      CHARACTER*2  IATOM
      CHARACTER*3  SYMBOL,ITAT
      CHARACTER*80 MNAM
 
      COMMON /CONVERT/IVERK,IPARA,IADEF,IADD,IDUMMY,ISUM,IDIST,IVA
 
      COMMON/FMO/NFMO,FMO(MXATOM),FMOCH(9),PRIFMO(7)
      INTEGER NFMO,FMO,FMOCH
      LOGICAL PRIFMO
 
      COMMON/KSET/KATOM(MXSETK,2),SETK(MXSETK),SETD(MXSETK),NKSET
 
      COMMON /NEWDI/ CWK,CWKALP
 
      COMMON/OMITRP/NOMIT,OMIT(MXOMIT)
      INTEGER NOMIT,OMIT
 
      COMMON/PARAM/NH,NA,KA,METH,IPRINT,IPUNCH,L1,L2,L3,L4,L5,L6,L7,
     .             L8,L9,PRT
      LOGICAL L1,L2,L3,L4,L5,L6,L7,L8,L9,PRT(24)
 
      WRITE(6,10)
10    FORMAT(////,
     .'  ***********************************************************',/,
     .'  *                    I C O N - E D i T                    *',/,
     .'  *                  Release September 1997                 *',/, 
     .'  *                       I N P U T C                       *',/,
     .'  *  -----------------------------------------------------  *',/,
     .'  *              Input Program for EHMO ICONC               *',/, 
     .'  *                          -----                          *',/,
     .'  *      Gion Calzaferri, Ruedi Rytz, Martin Braendle,      *',/,          
     .'  *          Dominik Bruehwiler and Stephan Glaus           *',/,
     .'  *        Department of Chemistry and Biochemistry         *',/,
     .'  *             University of Bern, Switzerland             *',/,
     .'  *                                                         *',/,
     .'  *               (C) 1997 by Gion Calzaferri               *',/,
     .'  * INPUTC comes with absolutely no warranty. This is free  *',/,
     .'  *     software and you are welcome to redistribute it     *',/,
     .'  *                under certain conditions.                *',/,
     .'  *       For details see GNU General Public License.       *',/,
     .'  ***********************************************************',/,
     .2X)
C
C Programm-Varianten
C
      WRITE(6,20)
20    FORMAT(  '  **********************************************',/
     .         '  *  1  Cartesian coordinates                  *',/
     .         '  *  2  Internal coordinates (with variations) *',/
     .         '  *  3  Conversion of file from #2             *',/
     .         '  *  0  End                                    *',/
     .         '  **********************************************',/)
   30 WRITE (6,40)
   40 FORMAT($,' Option # : ')
      READ(5,*,ERR=30) IVA
      IF (IVA .EQ. 0) GOTO 50
      IF ((IVA .LT. 0) .OR. (IVA .GT. 3)) GOTO 30
      IF ((IVA .GT. 0) .AND. (IVA .LT. 3)) THEN
        CALL ATOMREAD
        CALL INPFI (IVA,FILE1,FILE2,FILE3)
        CALL CASE1 (FILE1)
      ENDIF
      IF (IVA .EQ. 3) CALL INPFI(IVA,FILE1,FILE2,FILE3)
      IF (IVA .GT. 1) THEN
        MOBYC=0
        CALL GENIC(FILE1,FILE2,MOBYC)
        CALL CONVC(FILE2,FILE3,MOBYC,FILE1)
      ENDIF
   50 END
